# On patents & databooks: A conversation about the making of Performing Patents Otherwise.

*Performing Patents Otherwise* is one of several experimental book pilot projects conducted by the experimental publishing group of the Community-led Open Publication Infrastructures for Monographs project. In the spirit of open infrastructures, we document the publication process for each pilot book in the hope that it will be helpful to fellow authors and publishers exploring the possibilities of experimental scholarly publishing. This blog post provides an overview of the publishing process of *Performing Patents Otherwise.*

*Performing Patents Otherwise* is based on Kat Jungnickel’s European Research Council funded research project [*Politics of Patents*](https://www.politicsofpatents.org/) (POP) at Goldsmiths, University of London. Kat and her team set out to do a mixed-methods analysis of an extensive global database of historical clothing patents that covers around 300,000 entries covering a period of 200 years. Using a combination of quantitative and qualitative approaches, including ethnographic and speculative sewing methods, the POP project investigates the changing nature of citizenship, gender relations and public space over time via historic clothing patent data. But there is much more to be explored in this unique dataset. Sharing large amounts of data poses the question of how such a massive archive can be navigated, sorted and made sense of while staying committed to a careful and detailed reading of the material. Database books provide one answer to how large amounts of open-access material can be made available without dumping the labour of sense-making on the reader or presenting simplified accounts that render the underlying complexity and diversity of the material invisible. 

## Database Books

The experimental publishing group published an [Experimental Publishing Compendium](https://compendium.copim.ac.uk/) alongside the three pilot books. The online Compendium collates tools, practices and book examples as a resource for authors and publishers interested in experimental scholarly publishing. At the same time, the accompanying report, [*Books Contain Multitudes*](https://copim.pubpub.org/books-contain-multitudes-exploring-experimental-publishing-2022-update)*, *also established a tentative typology of experimental books. We categorise *Performing Patents Otherwise* in the Compendium and the report as a database book. We define database books as books that contain a dynamically searchable database within their pages; or books generated from a database. 

## A collective achievement

Kat Jungnickel from the POP project and Julien McHardy from [Mattering Press](https://www.matteringpress.org/) initiated the project and closely collaborated from conceptualising to writing and production. Our collaboration highlights that in experimental publishing, the role of publishers, authors and editors tend to be less clearly distinguished than in established publishing workflows. Simon Bowie, who did much of the backend coding, made it possible to integrate a fully searchable database of around 300,000 clothing patents, and far from just being technical, this work shaped how the book works and, thus, how it can be read. Joana Chicau — a professional dancer, coder and designer — worked with us to create several ways of navigating the book without becoming overwhelming. Her understanding of interface design as a kind of choreography shaped this book project in ways that go far beyond its look and feel. 

Our collective exploration of what a database book might be changed the process of publishing and challenged our functions in the publishing process as coders, designers, authors, editors and publishers. To capture that this shift has different implications for each of the involved roles, we choose to have a chat with the book publishing team to document our process. 

We recorded this conversation during the launch of the beta version of  *Performing Patents Otherwise* on 15 April 2023 at [Varia](https://vvvvvvaria.org/category/event.html), Rotterdam. The following is an edited transcript of our conversation.

## Making *Performing Patents Otherwise*.

![Recording the making of interview at Varia, Rotterdam, 15/4/23](/static/images/making-of-1.jpeg)
*Recording the making of interview at Varia, Rotterdam, 15/4/23*

**Julien McHardy** Could you share your role in making this book?

**Simon Bowie** I’m Simon. I’m a developer at the *Centre for Postdigital Cultures* in Coventry. I work on the COPIM project for open infrastructures for monograph publishing and *Performing Patents Otherwise* is one of our experimental pilot publishing projects. I was brought on to develop the backend and the database for this kind of data book.

**Joana Chicau** I’m a designer working primarily with digital artefacts, interface design and human-computer interaction more broadly. I joined to design the database book the team put together and think with them about how to interface the data.

**Kat Jungnickel** I’m a reader in Sociology at Goldsmiths, University of London. I lead the ERC-funded research project *Politics of Patents, reimagining citizenship via clothing inventions from 1920 to 2020*. Our project is a multimedia and multi-methods exploration of clothing patent data around the world. I got involved in this database book project because it was an intriguing invitation to do something exciting and experimental with a lot of data that we are enthusiastic about. 

**Julien McHardy** I am a researcher, designer and publisher. When I came across Kat’s project, I was already thinking about databooks, about how books and databases could come together in new ways. And it struck me that there was this vast database and that you, Kat, were already working on finding different ways to access it. And that’s how our shared interest in bringing databases and books together started. 

*Performing Patents Otherwis*e is a digital book that contains, within its pages, a searchable database of around 300,000 historical clothing patents. You all met and modified this database at different points in the project. 

**Kat** Several years ago, I got very excited by patents as social science data and started to look into it in a small way. At first, it was only five years of UK data from 1890 to 1900. That small investigation whet my appetite for the treasure hidden in these archives. I was fortunate and put in a lot of work to get a bigger grant, a bigger team, and more time to dive further into global patent archives. We collected patent data, predominantly from the European Patent Office (EPO) Espacenet and several other patent scraping sites. We also spent time in patent offices in different countries looking at patents in paper form. However, COVID severely curtailed travel, so, we spent a lot of time online researching digitised patents. In the POP project, we approach the study of inventions documented in the patents inventively. We are interested in lesser-known stories, in rendering hidden stories visible and bringing to life what might appear dry and dusty or boring to some people. We wanted to tell stories of forgotten inventors who attempted to change the world sititch by stitch and we do this through writings, publications, film, reconstructed costume and performances ([see here for more](http://www.politicsofpatents.org/)). But there are so many other methodological lenses and theoretical understandings that you can put to this large dataset. So, we were interested in sharing the dataset in a way that invites others to conduct their own explorations. 

**Julien** A lot of patent data is openly accessible. Can you tell us about the work it took to make this open-access data useful for your research?

**Kat** It’s fantastic how much of this data is now available open-access and in digitised form. I think the EPO holds about 120 million patents. We’re looking at a small specific sample of clothing patents from 1820 onwards, and even that’s enormous. You can access this data via the EPO’s Espacenet database or run specific queries using MySQL in PATSTAT. So, it depends on how you want to scrape that data, how you want to look at it, and what you want to do with it. And it also depends on the skills you might have. And there are limitations to the data too. Especially with older data, your ability to see, understand and do things with it is very much defined by how it entered the dataset. The aged state of the paper patent, the nature the first lot of scanning, and the machine learning processes that were put to it, all give shape the gorgeous texture of some of these documents. However, it means some can’t be scanned because they’re handwritten or in poor condition. Digital instruments struggle with those kinds of things. Other patents don’t have titles, or abstracts, or there are a lot of spelling mistakes. Add a range of different languages, and interpretation can become challenging. 

We’ve worked hard to pull together about 300,000 data points from around the world, covering clothing inventions from 1820 to 2020. We cannot say this is all of them. The dataset keeps growing and changing even four years into the project. However, we’ve still assembled a unique resource by adding plenty of missing data, links to the openly accessible body of data and we brought it all into one language, which makes it more easily searchable.  

**Julien** You point to the difference between openly available data and data that is accessible and useful to a broader group of people. Data might be dumped in some open repository yet remain incredibly tough to access. Simon, we approached you to make the data accessible for people without the programming skills to run data queries and to think with us about how we can combine the virtues of curation with open exploration. 

**Simon** I was brought in to look at what we can do within a publication that would allow us to expose the dataset to a more general audience. At that point, Kat and her team had already curated, cleaned and structured the dataset. I got a folder of RTF files containing information such as patent ID, abstract, various notes, date, and country of application. With a background in library cataloguing and search systems development, my first thought was I can put this into a search engine and we’ll be able to search the entire dataset and find things more readily than by browsing this RTF folder.  

![Browsing chatelaine patent PDFs in the POP database](/static/images/making-of-2.png)
*Browsing chatelaine patent PDFs in the POP database*

I started bringing the data into a machine-readable form, but my first exposure to the dataset was less structured. I browsed the RTF files manually, just opening random files and seeing the patterns. And I found that an exciting way of discovering the dataset, just randomly finding a patent for activewear or another for bicycle trousers or whatever. And that became the core of what I wanted the reader to experience. I want you to experience that same sense of randomness. 

**Joana** When I joined, the entries could already be searched on a platform available from a URL. It was already under construction. There was a search engine, and I had to write the right keywords to be able to find content. And I remember encountering these curated folders of RTF files that Kat put together. I was on a flight, couldn’t connect to the internet, and was looking through the raw files locally on my computer. There were images and texts. What these curated words and images evoked was interesting already. A paper by Kat on the role of some of these patents for gender struggle further contextualised the patents [add link to paper?]. My random exploration of the RTF files during the flight and Kat’s feminist take on the patents gave me a taste of the possibilities for curation and randomness. 

**Julien** How did you approach entangling books and datasets as an interaction designer?

**Joana** My notion of a book was already pretty stretched, from previous work on blurring the line between printed and digital objects. Coming to this project, I felt a lot of freedom to push the format, and you don’t always have that with interaction design projects. Here we wanted to provide usability while questioning the expectation of smoothness by exposing some of the tensions in the data. I therefore focussed on the notion of performativity and how tensions within the dataset could become part of how people interact with it.

**Julien** Simon, you wrote an essay for *Performing Patents Otherwise* exploring how books and relational databases relate...

**Simon** A relational dataset is the backbone of many modern web applications. A relational database ties two pieces of data together by establishing a relationship. If you go to your banking website, your customer ID will be tied to your account balance, name, address, etc. The database ties these pieces of data together. There are a lot of relational databases out there. In our work at COPIM we use open-source versions like MySQL. But there’s Microsoft SQL and a whole host of commercial relational databases. 

For this project, I wanted to keep the structural benefits of a relational database while encouraging readers to discover serendipitous juxtapositions that would enable users to find and configure novel relationships between things. Usually, in a relational database, you explicitly tie two pieces of data together by clearly specifying their relationship, making an epistemological judgement that these two pieces of data or knowledge go together. Bringing up two random entries from the dataset, as we do in this book project, encourages you to make your own relationship or interpret relations based on what you see in the pattern. And that idea of subverting conventional relational structure was fascinating to me.

**Julien** Kat, as an author and editor, how was making this book different from a conventional book?

**Kat** Well, every book is unique, and usually ends up differently from what you intended depending on who you’re working with, and where the materials take you. This book and collaboration remind me of my favourite books as a kid: Choose-Your-Own-Adventure books. You didn’t follow a a singular, defined path through the book. You would get to a certain point, and then you were given choices and you could head off in different directions. And I love that way of subverting narratives by making up other narratives that allow you to explore a story in multiple forms. And I’ve always wanted to do this with a (scholarly) book. 

With this book project, we are relating some of the complexity of the materials in ways that more normative formats can’t. We invite readers to piece fragmented bits and pieces of data together in multiple ways while sharing stories we uncovered, trying to discover what motivated inventors and influenced them to articulate a particular issue. So, we want to share (1) the research we uncovered alongside (2) the possibility that other people might stumble across different parts of the dataset in search of different stories and experience new ways of piecing these stories together. And the very structure of this book aims to allow that.

**Julien** Joana, can you tell us how serendipitous, random browsing is implemented in the book? 

**Joana** I have a background in dance and performance. So, I’m inclined to think through movement in physical and digital spaces; and how we conceptualise and embody those movements. And I’m also interested in notation systems. My knowledge comes from dance, but notation systems are part of many practices. Movement and notation allow us to think about how we relate to data at the interface level. How the interface and the underlying infrastructures perform certain kinds of users and certain kinds of knowledge objects into being. Interface, user subjectivity and content are all performative, and it isn’t easy to coordinate or choreograph these layers of performativity. My intention was never to provide *one* way to do things but rather to introduce provocations or interferences. The *search interferences* we designed invite readers to read the patent data unexpectedly, offering more questions than answers. 

![*Poetics of Titles* search results](/static/images/making-of-3.png)
**Poetics of Titles* search results*

So, two interface features explicitly address the ambition to perform data otherwise: (1) the *six search interferences are* six different buttons a user can click to expose randomised parts of the dataset. To give one example, the *Poetics of Titles* grabs titles from ten data entries. It’s interesting to look at them relationally —representing different times, spaces, and geographies—giving a strange result inviting people to dig further. It’s a weird, weird reading of history because that’s what history is: weird. (2) The question mark menu toggles notations, providing a reflexive layer.

![Question mark menu toggling red notations](/static/images/making-of-4.png)
*Question mark menu toggling red notations*

**Julien** Simon, you mentioned that to search for something you usually need to know what you are looking for. And you contrast searching for the known with the experience of browsing a bookshop or library...

**Simon** I spent the better part of a decade as a library systems developer, working on designing and maintaining library systems and library catalogue systems. In a library system driven by a library search engine, you’re usually catering to particular kinds of search: You’re catering to a user who wants to find a book they’ve come across on a reading list or in a reference or a citation. And they want to find that one thing. Or they know at least what subject matter they are looking for. But that’s not the only way people use libraries. People also go to libraries and bookshops, look at the shelves, find books next to the one they’ve been looking for, or something random. That sense of serendipity is hard to replicate in digital environments such as search engines or library catalogues. There are commercial search engines and catalogues with random browsing features, but in my experience, they’re not very good. 

I have been working with randomness in previous projects. Before I came on to this project, I designed a piece of software that created a poem from randomly generated bits of text and I got one of those poems published. So, I was playing around with randomness. And I wanted to bring that kind of poetic randomness to this dataset. We implemented this through several features that pick out random records, for example, by stringing random titles together almost in the form of a poem, by getting random abstracts, or by juxtaposing abstracts side by side and seeing what kind of prose poems come out of that. So randomness was the kernel of the idea I was working with. There’s something liberating about deliberately going random in a cultural landscape dominated by the algorithmic processing of techno-capitalist titans like Google, Twitter, Facebook, or Amazon. It pushes against this algorithmic design philosophy, offering perhaps a more poetic way, allowing for the possibility of data being otherwise.

**Julien** We called the interfaces that work with randomness to expose unexpected parts of the archive *search interferences* because they interfere with the conventions of computational search. Besides the search interferences, the book contains *archival conversations*...

**Kat**From the project’s beginning, we wanted to invite people to converse with the data in multiple ways. In addition to POP’s core research deliverables, we experimented with several examples of what people might do with this data, and we call these *archival conversations.* The search interferences – are about discovery; the archival conversations are intimate engagements with the patents commissioned in collaboration with other practitioners. We have a sound piece; a performance piece and we showcase our practice of speculative sewing. The archival conversations explore what’s not explicit in the patent archive, intervening in the dataset’s colonial, gendered, and racial shaping. And we hope that they might inspire others to explore some of the archive’s buried stories.

![Video still from the archival conversation *I Martha Gowans*](/static/images/making-of-5.png)
*Video still from the archival conversation *I Martha Gowans*.*

**Julien** The archival conversations expose relationships within the data that computational search cannot reveal because, for example, labour, colonial and gender relations are not indexed in the data. 

**Kat** Finding ways of embodying the data, for example, by putting bodies back into these costumes that are otherwise just RTF files and PDFs, is central to my practice. It’s a way of diving into histories and thinking about their relevance today. And it’s something that we bring out in the larger research project and point to in this book through the archival conversations.

**Julien**Let’s turn to the nitty-gritty of making this dataset book. 

![Site architecture of *Performing Patents Otherwise* by Simon Bowie](/static/images/patents_site_architecture.png)
*Site architecture of *Performing Patents Otherwise* by Simon Bowie*

**Simon** I initially wrote the prototype in PHP. Down the line, I changed it into Python, rewriting the entire thing to enable smoother collaboration. Now it is essentially a Python application. The problem with the initial prototype was that everything was hardcoded in HTML, making it hard for others to contribute. So, we set up a markdown file structure that allows authors to write in Markdown, a writer-friendly What-You-See-Is-What-You-Get format. Once a new version of the text files is ready, we can copy those files directly into the Flask application and have Python convert it to HTML systematically, requiring little human intervention. So that works well as a workflow. After designing the initial prototype, I passed it over to Joana to make it more performative, fun, and easier to interact with. 

**Joana** I can only agree that it’s vital to have flexible formats that allow interdisciplinary teams to collaborate. I mainly worked with HTML, CSS and JavaScript to build the interaction design. 

**Julien** How did you implement COPIM’s commitment to open-source tools?

**Simon** We are using open-source tools. We are using the Flask framework to render the website. Search functions are provided by the Apache Solr Search Engine. Further, we’re linking the curated dataset to the European Patent Office’s open data API. And our open access licencing reflects our commitment to keeping things open-source.

**Joana** We’re also hosting all the code on a Gitea repository, so it can be used by other people.. 

**Julien** How do you navigate the tension between keep things open and the ambition to create project and data specific designs?

**Joana** We’re using mainly open-source tools, and the model we established could be reproduced, but we’re not using templates or a framework where you’re one click away from putting together a project of this kind. Our modular approach allows you to pull apart and reuse components, adapting them to specific data and collaborators. So, there’s a balance between having reusable components and specific designs. At the same time, I am sceptical of universal solutions and one-size fits all approaches. And there is a question of scale: I wouldn’t know if the same solution would make sense for larger projects involving more people and dependencies. 

**Julien** Kat, how did making this book differ from other books you’ve written? 

**Kat** This project started wide open. That was exciting but daunting because I didn’t know how and when to shape or stand back from it. We developed this in a collective way, which may not happen with different groups, timescales or pressures. But, in our case, it turned into this collective thing where we explored content, roles and format simultaneously. I want to turn the question of how this book project differed from others back to you, Julien, because you’ve worked on various publications?

**Julien** It was great to build a group of people who committed to this experiment, not knowing what would come from it. This required everyone to be flexible in terms of roles and expectations. It was strange and wonderful to make this open invitation: to say we are working on this thing, and we don’t quite know what it is, and we would like to do it with you. We learned that experimenting with books involves experimenting with authority and publishing functions. There was a lack of hierarchy because we had to negotiate where to take things, and how to allow everyone to shape the project with their expertise and ideas. This also means that responsibilities weren’t always straightforward. Roles such as editor, author or publisher became blurred. And deviating from conventions creates a tremendous amount of additional work, which throws up funding, recognition, responsibility and labour questions. It’s tough, for example, to get funding for design, and it’s hard to finance development with academic funding. Financing experimental work, therefore, often requires patchworking funding from other pots, so it’s worth flagging this problem of financing non-academic contributors to funders. 

Thinking further about what to share with scholarly writers or publishers setting out to make database books, I recommend bringing the team together as early as feasible. Design and coding will shape databook experiments, so it’s important to include designers and coders from the project’s conception. 

**Kat** As a researcher, I want to tell these amazing stories that we’ve discovered and invite people into these different worlds that we’d stumbled upon and had the privilege to spend time in. When I started *Politics of Patents*, I hoped to find ways of sharing this rich data and the stories we unearth in an accessible way. I envisioned putting them into an open-access data repository at that point. There are plenty of open data repositories, and while they are precious resources, they can be difficult to access; more data dumps than usable datasets. You usually need to know what is in these databases to use them. By contrast, databooks like *Performing Patents Otherwise* have the potential to share research analysis and source data in an accessible fashion, inviting people into the data, showcasing examples of use and providing tools to dive into it. 

**Simon** We’ve all talked about our different perspectives on the dataset and the book. Bringing together researchers, developers, designers, and publishers broadens the scope of what can be done if you encourage open communication between the people involved. As a developer, if a researcher brings me in early on the project, I can advise what can be done with a dataset that might make it more interesting. And working with Joana as an interface designer has been really good for pushing the design, foregrounding performativity in ways that I wouldn’t have thought of. 

**Joana** When it comes to experimental projects like this one, it’s good to push the boundaries of interface design and what it means to publish while keeping in mind accessibility. For as much as you’re providing an experience intended to be different, it’s critical to ensure that some of the standards and protocols are in place that allow rendering content for different purposes and modes of accessibility. 

I’m excited to see how this work spreads and how people use it. *Get in touch if you’re setting out on a databook adventure.*