# Interfacing Data

*an essay by [Joana Chicau](https://joanachicau.com/)*

Upon arriving at the landing page, one finds a centered bar inviting to ‘search for a patent record’. If a search is performed, a ‘timeline of inventions’ displays the results. The timeline can be filtered by year, country and sorted by relevance or chronological order.

Back to the landing page, around the search bar there are six other routes to the dataset, here referred to as search *interferences*. These *interferences* invite for unexpected readings of the dataset. Each of them is named in relation to what the code does, yet described in a poetic manner, as a way to open up to various possible readings.

The latter connects with the notion of performativity of the code. The performativity of code refers to "its ability to act and perform as in speech act theory" (Arns, 2005, pp. 2). Speech Act theory by Austin (2009), defines performative speech acts as sentences that simultaneously describe and also do the thing that is being described. Thus, saying and doing are intertwined. This performative quality "is not to be understood as a purely technical performativity, ie, it does not only happen in the context of a closed technical system, but affects the realm of the aesthetic, political and social." (Arns, 2005, pp. 7)

*Interferences* provide different routes for users to explore the dataset through different viewpoints and relationalities.

```
<a href=".../titles/">a poetics of titles</a>
```

```
<a href=".../fragments/">a handful of fragments</a> 
```

```
<a href=".../scattering/">a scattering of images</a>
```

```
<a href=".../random/">a random entry</a> 
```

```
<a href=".../juxtaposition/">a juxtaposition of two</a>
```

```
<a href=".../data/">mapping the archive</a> 
```

The performative elements are stretched to other parts of the interface, such as *operations* that invite for interaction, acting as scores that perform certain actions such as:

```
 + 
```

Adds entries from the dataset to displayed on screen;

```
 -  
```

Removes entries from the dataset being displayed on screen;

```
 ↻   
```

Refreshes the page which make entries being displayed change;

In addition, a series of *<!-- comments -->* populate the platform which provide further insight on what the underlying code does as.

*Interferences*, *<!-- comments -->* and *operations* aim at creating a new layer of interpretation, engagement and meaning. Altogether they can be seen a form of binding notations across the interface. Notations operate differently depending on the field at stake, "ranging from colloquial use for various note-making practices, to other forms of score, script, recipe, or diagrammatic map, to the development of a formalized notation system with its own clearly defined inner logic." (Blackwell et al, 2022, pp.127).

These notations both increase the legibility of the algorithmic logic behind the interface and function as a playful mode of interaction. These notations are also an exercise to question the “visibly invisible essence” (Wendy Chun, 2008, p. 2) of software by highlighting its inner workings and how data is computed.

This interface aims to be a reflexive site for the critical exploration of the data it holds. In the words of Wendy Chun, "if code is performative, its effectiveness relies on human and machinic rituals." (2008, p. 13). In this vein, Performing Patents Otherwise more broadly reflects on how we relate to search engines in our day-to-day. And asks how these rituals may nurture more legible, interpretative, critical and open-ended ways of relating to the data that surrounds us?

**References**

* Arns, I. (2005) ‘Code as performative speech act’, *Artnodes*, 0(4). Available at: <https://doi.org/10.7238/a.v0i4.727>.

* Austin, J.L. and Urmson, J.O. (2009) *How to do things with words: the William James lectures delivered at Harvard University in 1955*. 2. ed., [repr.]. Cambridge, Mass: Harvard Univ. Press.

* Blackwell, Alan F.; Cocker, Emma; Cox, Geoff; McLean, Alex; Magnusson, Thor. (2022) *Live Coding: A User’s Manual*. The MIT Press. Available at: <https://doi.org/10.7551/mitpress/13770.001.0001>.

* Wendy Hui Kyong Chun (2008) ‘On “Sourcery,” or Code as Fetish’, *Configurations*, 16(3), pp. 299–324. Available at: <https://doi.org/10.1353/con.0.0064>.